Mozilla and Java properties files — Translate Toolkit 3.3.3 documentation

# Mozilla and Java properties files

The Translate Toolkit can manage Java .properties files with the prop2po and po2prop tool. As part of the Mozilla localisation process, the moz2po tool handles the properties files along with the other files. The tools can also handle Skype .lang files. Some related formats with their own documentation:

- Mac OSX strings

- Adobe Flex properties files.

## Features

- Fully manage Java escaping (Mozilla non-escaped form is also handled)

- Preserves the layout of the original source file in the translated version

New in version 1.12.0.

- Mozilla accelerators – if a unit has an associated access key entry then these are combined into a single unit

## Not implemented

- We don’t allow filtering of unchanged values. In Java you can inherit translations, if the key is missing from a file then Java will look to other files in the hierarchy to determine the translation.

## Examples

    editmenu.label = "Edit"
    saveas.label = "Save As"

## References

- Java Properties Class’s load() describes the properties format.

- http://www.oracle.com/webfolder/technetwork/jsc/dtd/properties.dtd – alternate XML based property representation